Computes the Breslow estimator of the baseline hazard function for a proportional hazard regression model.
Arguments
- t
The survival times.
- delta
The censoring indicator.
- f.x
The predicted values of the regression model on the log hazard scale.
- t.eval
Values at which the baseline hazard will be evaluated.
- smooth
If
TRUEbasehaz.gbmwill smooth the estimated baseline hazard using Friedman's super smoothersupsmu.- cumulative
If
TRUEthe cumulative survival function will be computed.
Value
A vector of length equal to the length of t (or of length
t.eval if t.eval is not NULL) containing the baseline
hazard evaluated at t (or at t.eval if t.eval is not
NULL). If cumulative is set to TRUE then the returned
vector evaluates the cumulative hazard function at those values.
Details
The proportional hazard model assumes h(t|x)=lambda(t)*exp(f(x)).
gbm can estimate the f(x) component via partial likelihood.
After estimating f(x), basehaz.gbm can compute the a nonparametric
estimate of lambda(t).
References
N. Breslow (1972). "Discussion of `Regression Models and Life-Tables' by D.R. Cox," Journal of the Royal Statistical Society, Series B, 34(2):216-217.
N. Breslow (1974). "Covariance analysis of censored survival data," Biometrics 30:89-99.
Author
Greg Ridgeway gregridgeway@gmail.com