basehaz.gbm(t, delta, f.x, t.eval = NULL, smooth = FALSE, cumulative = TRUE)TRUE basehaz.gbm will smooth the estimated baseline hazard using Friedman's super smoother supsmuTRUE the cumulative survival function will be computed t.eval if t.eval is not NULL) containing the baseline hazard evaluated at t (or at t.eval if t.eval is not NULL). If cumulative is set to TRUE then the returned vector evaluates the cumulative hazard function at those values.
gbm can estimate the f(x) component via partial likelihood. After estimating f(x), basehaz.gbm can compute the a nonparametric estimate of lambda(t).
N. Breslow (1974). "Covariance analysis of censored survival data," Biometrics 30:89-99.
survfit, gbm