gbm object and
optionally plots various performance measures
gbm.perf(object, plot.it = TRUE, oobag.curve = FALSE, overlay = TRUE, method)gbm.object created from an initial call to
gbm.plot.it=TRUE creates two plots. The first plot plots
object$train.error (in black) and object$valid.error (in red)
versus the iteration number. The scale of the error measurement, shown on the
left vertical axis, depends on the distribution argument used in the
initial call to gbm.method="OOB" computes the out-of-bag
estimate and method="test" uses the test (or validation) dataset
to compute an out-of-sample estimate. method="cv" extracts the
optimal number of iterations using cross-validation if gbm was called
with cv.folds>1gbm.perf returns the estimated optimal number of iterations. The method
of computation depends on the method argument.gbm, gbm.object