gbm stores the collection of trees used to construct the model in a
compact matrix structure. This function extracts the information from a single
tree and displays it in a slightly more readable form. This function is mostly
for debugging purposes and to satisfy some users' curiosity.
pretty.gbm.tree(object, i.tree = 1)gbm.object initially fit using gbmobject
and display pretty.gbm.tree returns a data frame. Each row corresponds to a node in
the tree. Columns indicate
object$c.split that describes the categorical
split. If the node is a terminal node then this is the prediction.gbm, gbm.object