Skip to contents

Marks the quantiles on the axes of the current plot.

Usage

# S3 method for class 'rug'
quantile(x, prob = 0:10/10, ...)

Arguments

x

A numeric vector.

prob

The quantiles of x to mark on the x-axis.

...

Additional optional arguments to be passed onto rug

Value

No return values.

See also

Author

Greg Ridgeway gregridgeway@gmail.com.

Examples

x <- rnorm(100)
y <- rnorm(100)
plot(x, y)
quantile.rug(x)