Marks the quantiles on the axes of the current plot.
Usage
# S3 method for class 'rug'
quantile(x, prob = 0:10/10, ...)Arguments
- x
A numeric vector.
- prob
The quantiles of x to mark on the x-axis.
- ...
Additional optional arguments to be passed onto
rug
Author
Greg Ridgeway gregridgeway@gmail.com.