Helper function to reconstitute the data for plots and summaries. This function is not intended for the user to call directly.
Arguments
- x
a
gbm.objectinitially fit usinggbm
Value
Returns a data used to fit the gbm in a format that can subsequently be used for plots and summaries