relative.influence(object, n.trees)
permutation.test.gbm(object, n.trees)
gbm.loss(y,f,w,offset,dist,baseline)gbm object created from an initial call to gbm.gbm.loss: These components are the
outcome, predicted value, observation weight, offset, distribution, and comparison
loss function, respectively.summary.gbm.
gbm.loss is a helper function for permutation.test.gbm.L. Breiman (2001). "Random Forests," Available at
summary.gbm