Run tests on gbm functions to perform logical checks and
reproducibility.
Details
The function uses functionality in the RUnit package. A fairly small
validation suite is executed that checks to see that relative influence
identifies sensible variables from simulated data, and that predictions from
GBMs with Gaussian, Cox or binomial distributions are sensible,